@@ -1,4 +1,4 @@
-/* $Id: remap.c,v 1.14 2004/09/14 22:38:46 hpa Exp $ */
+/* $Id: remap.c,v 1.15 2004/09/23 02:22:02 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001-2004 H. Peter Anvin - All Rights Reserved
@@ -234,7 +234,8 @@ static int parseline(char *line, struct rule *r, int lineno)
   if ( !(r->rule_flags & RULE_REWRITE) )
     r->rule_flags &= ~RULE_GLOBAL;
 
-  if ( r->rule_flags & (RULE_INVERSE|RULE_REWRITE) ) {
+  if ( (r->rule_flags & (RULE_INVERSE|RULE_REWRITE)) ==
+       (RULE_INVERSE|RULE_REWRITE) ) {
     syslog(LOG_ERR, "r rules cannot be inverted, line %d: %s\n", lineno, line);
     return -1;			/* Error */
   }
