@@ -1,4 +1,4 @@
-/* $Id: remap.h,v 1.5 2001/11/16 23:38:29 hpa Exp $ */
+/* $Id: remap.h,v 1.6 2002/11/08 01:10:09 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001 H. Peter Anvin - All Rights Reserved
@@ -37,7 +37,7 @@ void freerules(struct rule *);
 
 /* Execute a rule set on a string; returns a malloc'd new string. */
 char *rewrite_string(const char *, const struct rule *, int,
-		     match_pattern_callback);
+		     match_pattern_callback, const char **);
 
 #endif /* WITH_REGEX */
 #endif /* TFTPD_REMAP_H */
